﻿// Upgrade NOTE: replaced 'mul(UNITY_MATRIX_MVP,*)' with 'UnityObjectToClipPos(*)'

Shader "Custom/PaintShader" {
    Properties {
        _MainTex ("Albedo (RGB)", 2D) = "white" {}
        _PaintTex ("Paint (RGB)", 2D) = "white" {}
        _PaintOffset ("Paint Texture Offset", Vector) = (0.5,0.5,0,0)
        _PaintScale ("Paint Texture Decal Scale", Float) = 0.1
    }

    SubShader {
        Tags {"RenderType"="Opaque"}
        Pass {
            Name "Paint"
            Cull Back
            ZWrite On
            Lighting On
            CGPROGRAM
            #include "UnityCG.cginc"
            struct appdata
			{
                float4 vertex : POSITION;
                float3 normal : NORMAL;
                float4 texcoord : TEXCOORD0; 
            };
            struct v2f
			{
                float4 pos : SV_POSITION;
                float2 uv : TEXCOORD0;
                float2 paintuv : TEXCOORD1;
            };
            uniform float4 _PaintOffset;
            uniform float _PaintScale;
            v2f vert(appdata_base v)
			{
                v2f o;
                o.pos = UnityObjectToClipPos(v.vertex);
                float3 norm = mul ((float3x3)UNITY_MATRIX_IT_MV, v.normal);
                o.uv = v.texcoord;
                o.paintuv = mul(UNITY_MATRIX_M, v.vertex).xz * _PaintScale + _PaintOffset;
                return o;
            }
            #pragma vertex vert			
            #pragma fragment frag
            sampler2D _MainTex;
            sampler2D _PaintTex;
            fixed4 frag(v2f input) : SV_Target
            {
                fixed4 base = tex2D(_MainTex, input.uv);
                fixed4 paint = tex2D(_PaintTex, input.paintuv);
                return lerp(base, paint, paint.a);
            }
            ENDCG
        }  
    }
    FallBack "Diffuse"
}
