﻿using UnityEngine;
using UnityEngine.Networking;

/// <summary>
/// ペイント弾処理
/// </summary>
public class Bullet : NetworkBehaviour
{
    [SerializeField] private Material[] colors;
    [SerializeField] private int damage = 10;

    [SyncVar] public int shooterNumber;
    [SyncVar] public float paintScale = 1f;
    [SyncVar] public float shootClock;
    [SyncVar] public Vector3 initialVelocity;
    [SyncVar] public Vector3 initialPosition;

    public override void OnStartClient()
    {
        foreach (var r in GetComponentsInChildren<Renderer>()) {
            r.material = colors[shooterNumber];
        }
        transform.localScale *= paintScale;
        SetCurrentPosition();
    }

    void FixedUpdate()
    {
        SetCurrentPosition();
    }

    public void SetCurrentPosition()
    {
        var acc = new Vector3(0f, -10.0f, 0f);
        var t = GameController.instance.worldClock - shootClock;
        transform.position = initialPosition + initialVelocity * t + 0.5f * t * t * acc;
    }

    void OnTriggerEnter(Collider collider)
    {
        if (!isServer) { return; }

        var layer = collider.gameObject.layer;
        if (layer == LayerMask.NameToLayer("Wall")) {
            OnHitWall();
        } else if (layer == LayerMask.NameToLayer("Player")) {
            OnHitPlayer(collider.gameObject);
        }
    }

    private void OnHitWall()
    {
        NetworkPaintEnv.instance.Paint(transform.position, shooterNumber, paintScale);
        Destroy(gameObject);
    }

    private void OnHitPlayer(GameObject hitObj)
    {
        var player = hitObj.GetComponent<PlayerCharController>();
        if (player != null && player.colorNumber != shooterNumber) {
            var combat = hitObj.GetComponent<Combat>();
            if (combat != null) {
                combat.TakeDamage(damage);
            }
            Destroy(gameObject);
        }
    }
}