﻿using System;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.Networking;

/// <summary>
/// ゲーム中のキャラクタのHealth管理
/// </summary>
public class Combat : NetworkBehaviour
{
    [SyncVar] public int health = 100;

    public int maxHealth = 100;
    [SerializeField] private bool destroyOnDeath = false;
    [SerializeField] private Transform hitEffectPrefab;

    /// <summary>
    /// 死んだときのイベント。server だけ。
    /// </summary>
    [NonSerialized] public UnityEvent onDead = new UnityEvent();

    private UnityEngine.AI.NavMeshAgent agent;
    private CharacterAnimatorController charAnimCtrl;

    private Vector3 spawnPoint;
    private Vector3 spawnForward;

    void Awake()
    {
        agent = GetComponent<UnityEngine.AI.NavMeshAgent>();
        charAnimCtrl = GetComponent<CharacterAnimatorController>();
        health = maxHealth;
    }

    public override void OnStartClient()
    {
        spawnPoint = transform.position;
        spawnForward = transform.forward;
    }

    public float GetMaxHealth()
    {
        return maxHealth;
    }

    public void TakeDamage(int damage)
    {
        if (!isServer)
            return;

        health -= damage;
        if (health <= 0f) {
            onDead.Invoke();
            if (destroyOnDeath) {
                Destroy(gameObject);
            } else {
                health = maxHealth;
                WarpToSpawnPoint();
            }
        }
    }
    public void WarpToSpawnPoint()
    {
        agent.Warp(spawnPoint);
        transform.forward = spawnForward;
    }

    internal void AttackHitByPlayer(int damage)
    {
        if (isServer) {
            TakeDamage(damage);
            charAnimCtrl.GetDamage();
        }
        if (hitEffectPrefab != null) {
            var emitPos = transform.position + Vector3.up * 1f;
            Instantiate(hitEffectPrefab, emitPos, Quaternion.identity);
        }
    }
}
