﻿using UnityEngine;
using UnityEngine.Assertions;
using UnityEngine.Networking;

/// <summary>
/// 敵（アイテムを落とす）キャラクタ処理。
/// </summary>
public class EnemyController : NetworkBehaviour
{
    [SerializeField] public ItemController[] dropItems;
    private UnityEngine.AI.NavMeshAgent agent;
    private float timeUntilChangeTarget;
    private CharacterAnimatorController animatorController;

    void Awake()
    {
        agent = GetComponent<UnityEngine.AI.NavMeshAgent>();
        animatorController = GetComponent<CharacterAnimatorController>();
        var combat = GetComponent<Combat>();
        if (combat != null) {
            combat.onDead.AddListener(OnDead);
        }
    }

    public override void OnStartServer()
    {
        animatorController.enabled = true;
    }

    void Update()
    {
        if (isServer == false) {
            return;
        }
        UpdateAgent();
        UpdateAnimator();
    }

    private void UpdateAgent()
    {
        if (timeUntilChangeTarget > 0f) {
            timeUntilChangeTarget -= Time.deltaTime;
            return;
        }
        timeUntilChangeTarget = UnityEngine.Random.value * 5f + 10f;
        var dest = UnityEngine.Random.insideUnitCircle;
        UnityEngine.AI.NavMeshHit hit;
        if (UnityEngine.AI.NavMesh.SamplePosition(new Vector3(dest.x, 0f, dest.y) * 20f, out hit, 25f, UnityEngine.AI.NavMesh.AllAreas)) {
            agent.destination = hit.position;
        }
    }

    private void UpdateAnimator()
    {
        var spd = agent.velocity.magnitude;
        if (!animatorController.IsState(GameAnimType.BlockLocomotion)) {
            animatorController.SetLocomotion(spd > 0.1f);
        }
    }

    private void OnDead()
    {
        if (dropItems == null || dropItems.Length == 0) {
            return;
        }
        var drop = dropItems[Random.Range(0, dropItems.Length - 1)];
        var item = Instantiate(drop.transform, transform.position + Vector3.up * 1f, Quaternion.identity) as Transform;
        Assert.IsNotNull(item);
        NetworkServer.Spawn(item.gameObject);
    }
}
