﻿using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Networking;

/// <summary>
/// 敵（アイテムを落とす）キャラクタを作る。
/// </summary>
public class EnemySpawner : NetworkBehaviour
{
    [SerializeField] private GameObject enemyPrefab;
    [SerializeField] private int spawnNum = 5;
    [SerializeField] private Transform[] spawnPoints;

    private List<GameObject> enemies = new List<GameObject>();
    private int spawnIndex;
    private const float spawnInterval = 20f;
    private float remainTimeNextSpawn;

    public override void OnStartServer()
    {
        foreach (var t in spawnPoints) {
            t.gameObject.SetActive(false);
        }
        Spawn(spawnNum);
        remainTimeNextSpawn = spawnInterval;
    }

    void Update()
    {
        enemies.RemoveAll(go => go == null);
        if (enemies.Count >= spawnNum) {
            return;
        }
        if (remainTimeNextSpawn > 0f) {
            remainTimeNextSpawn -= Time.deltaTime;
        } else {
            remainTimeNextSpawn = spawnInterval;
            Spawn(spawnNum - enemies.Count);
        }
    }

    private void Spawn(int n)
    {
        for (var i = 0; i < n; ++i) {
            var pos = spawnPoints[spawnIndex % spawnPoints.Length].position;
            var rot = Quaternion.Euler(0, Random.value * 360f, 0);
            var enemy = (GameObject) Instantiate(enemyPrefab, pos, rot);
            enemies.Add(enemy);
            NetworkServer.Spawn(enemy);
            ++spawnIndex;
        }
    }
}
