﻿using UnityEngine;

/// <summary>
/// health バー表示
/// </summary>
public class HealthBar : MonoBehaviour
{
    private GUIStyle healthStyle;
    private GUIStyle backStyle;
    private Combat combat;
    private PlayerCharController player;

    void Start()
    {
        combat = GetComponent<Combat>();
        player = GetComponent<PlayerCharController>();
    }

    void OnGUI()
    {
        InitStyles();

        // Draw a Health Bar
        Vector3 pos = Camera.main.WorldToScreenPoint(transform.position);

        // draw health bar background
        GUI.color = Color.grey;
        GUI.backgroundColor = Color.grey;
        GUI.Box(new Rect(pos.x - 26, Screen.height - pos.y + 20, combat.maxHealth / 2, 7), ".", backStyle);

        // draw health bar amount
        GUI.color = Color.green;
        GUI.backgroundColor = Color.green;
        GUI.Box(new Rect(pos.x - 25, Screen.height - pos.y + 21, combat.health / 2, 5), ".", healthStyle);

        if (player != null) {
            GUI.Label(new Rect(pos.x - 25, Screen.height - pos.y - 110, 60, 20), player.playerName, GUI.skin.textArea);
        }
    }

    void InitStyles()
    {
        if (healthStyle == null) {
            healthStyle = new GUIStyle(GUI.skin.box);
            healthStyle.normal.background = MakeTex(2, 2, new Color(0f, 1f, 0f, 1.0f));
        }

        if (backStyle == null) {
            backStyle = new GUIStyle(GUI.skin.box);
            backStyle.normal.background = MakeTex(2, 2, new Color(0f, 0f, 0f, 1.0f));
        }
    }

    Texture2D MakeTex(int width, int height, Color col)
    {
        Color[] pix = new Color[width * height];
        for (int i = 0; i < pix.Length; ++i) {
            pix[i] = col;
        }
        Texture2D result = new Texture2D(width, height);
        result.SetPixels(pix);
        result.Apply();
        return result;
    }
}