﻿using UnityEngine;
using UnityEngine.UI;

/// <summary>
/// ゲーム中の時間、プレーヤーポイント表示
/// </summary>
public class Hud : MonoBehaviour
{
    public static Hud instance { get; private set; }

    public PaintEnv paint;
    public Slider[] occupationGauges;
    public Text[] playerNames;
    public Text[] occupationRatio;
    public Text gameTime;
    public GameObject timeUp;
    public Text countDownChar;

    public void Init()
    {
        instance = this;
        for (var i = 0; i < occupationGauges.Length; ++i) {
            occupationGauges[i].gameObject.SetActive(false);
            occupationGauges[i].value = 0f;
        }
        timeUp.SetActive(false);
        countDownChar.gameObject.SetActive(false);
    }

    void Update()
    {
        for (var pn = 0; pn < occupationGauges.Length; ++pn) {
            var g = occupationGauges[pn];
            if (g.gameObject.activeSelf == false) {
                continue;
            }
            var ratio = paint.GetOccupationRate(pn);
            g.value = ratio;
            occupationRatio[pn].text = string.Format("{0:0.0}%", ratio * 100f);
        }
    }

    public void ShowOccupationGauge(int playerNumber)
    {
        if (occupationGauges[playerNumber].gameObject.activeSelf == false) {
            occupationGauges[playerNumber].gameObject.SetActive(true);
        }
    }

    public void SetCountDown(float t)
    {
        var active = (t > 0f);
        if (active != countDownChar.gameObject.activeSelf) {
            countDownChar.gameObject.SetActive(active);
        }
        var cdNum = (int) t;
        countDownChar.text = cdNum > 0 ? cdNum.ToString() : "GO!";
    }

    public void SetTime(float remainingTime)
    {
        if (remainingTime <= 0f) {
            timeUp.SetActive(true);
            gameTime.text = "0";
        } else {
            gameTime.text = ((int) remainingTime).ToString();
        }
    }
}
