﻿using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Networking;

/// <summary>
/// 背景ペイントのネットワーク処理
/// </summary>
public class NetworkPaintEnv : NetworkBehaviour
{
    public static NetworkPaintEnv instance { get; private set; }
    public float paintSize = 3f;

    private int serverPaintId = 0;
    private List<PaintData> paintData = new List<PaintData>();
    private PaintEnv paint;
    private int clientPaintId = 0;

    void Awake()
    {
        paint = GetComponent<PaintEnv>();
        instance = this;
    }

    public override void OnStartClient()
    {
        paint.Clear();
    }

    public void Paint(Vector3 position, int colorNumber, float paintScale)
    { // サーバーだけ実行。0,1,2...と番号をつけて順番にclientのRPCを呼ぶ
        if (isServer) {
            RpcPaint(serverPaintId++, position, colorNumber, paintScale, Random.Range(0, 360));
        }
    }

    [ClientRpc]
    public void RpcPaint(int id, Vector3 position, int colorNumber, float paintScale, int rotation)
    { // サーバーの呼び出しから id の順にPaintEnvにpaintをする。
        paintData.Add(new PaintData(id, position, colorNumber, paintScale, rotation));
    }

    void Update()
    {
        while (true) {
            var pd = paintData.Find(d => d.id == clientPaintId);
            if (pd == null) {
                return;
            }
            paint.AddNewPaint(pd.position, pd.colorNumber, paintSize * pd.paintScale, pd.rotation);
            clientPaintId++;
        }
    }

    public PaintedState GetPaintState(int colorNumber, Vector3 position)
    {
        return paint.GetPaintState(colorNumber, position);
    }

    /// <summary>
    /// ペイント弾によるペイント１つ分のデータ
    /// </summary>
    private class PaintData
    {
        public int id;
        public Vector3 position;
        public int colorNumber;
        public float paintScale;
        public int rotation;
        public PaintData(int id, Vector3 position, int colorNumber, float paintScale, int rotation)
        {
            this.id = id;
            this.position = position;
            this.colorNumber = colorNumber;
            this.paintScale = paintScale;
            this.rotation = rotation;
        }
    }
}
