﻿using UnityEngine;
using System;

/// <summary>
/// キャラクタのスキルデータ。
/// 移動速度が早くなったり、攻撃力があがったり。
/// </summary>
[Serializable]
public class Skill
{
    public SkillType skillType;
    public float skillValue;
    public float remainingTime;

    public bool isAlive { get; private set; }
    public float effectValue { get; private set; }

    public Skill()
    {
        isAlive = true;
    }

    public void Update(PlayerCharController ply)
    {
        if (!isAlive)
            return;
        if (remainingTime > 0f) {
            remainingTime -= Time.deltaTime;
            isAlive = remainingTime > 0f;
        }
        switch (skillType) {
            case SkillType.RunningSpeedOnMyPaint:
                effectValue = ply.myPaintState == PaintedState.Mine ? skillValue : 0f;
                break;
            case SkillType.RunningSpeedOnOtherPaint:
                effectValue = ply.myPaintState == PaintedState.NotMine ? skillValue : 0f;
                break;
            default:
                effectValue = skillValue;
                break;
        }
    }
}

public enum SkillType
{
    PaintScale,
    RunningSpeed,
    RunningSpeedOnMyPaint,
    RunningSpeedOnOtherPaint,
    AttackDamage,
}